@@ -2,11 +2,11 @@
 #######################################################################
 """The convertor text to vector of features
 
-$Id: cloudcompare.py 53504 2009-07-21 14:36:33Z cray $
+$Id: cloudcompare.py 53516 2009-07-25 07:23:59Z cray $
 """
 __author__  = "Andrey Orlov, 2008"
 __license__ = "GPL"
-__version__ = "$Revision: 53504 $"
+__version__ = "$Revision: 53516 $"
 
 from math import log
 from text2vector import Text2Vector
@@ -18,8 +18,8 @@ class CloudCompare(object) :
         self.dcmin = dcmin
         
     def __call__(self,vs1,vs2) :
-        v1 = [(Text2Vector().normAndVector(x)) for x in vs1 ]
-        v2 = [(Text2Vector().normAndVector(x)) for x in vs2 ]
+        v1 = [ (sq,v) for sq,v in [(Text2Vector().normAndVector(x)) for x in vs1 ] if sq > 0 ]
+        v2 = [ (sq,v) for sq,v in [(Text2Vector().normAndVector(x)) for x in vs2 ] if sq > 0 ]
         av1 = Average()([ x[1] for x in v1])
         av2 = Average()([ x[1] for x in v2])
         d1 = {}
